@@ -1,6 +1,5 @@
 use anyhow::{anyhow, Context, Result};
 use serde::Deserialize;
-// use webbrowser;
 
 use crate::config;
 use crate::gitlab::{Client, ProjectBuilder, Query};
@@ -16,17 +15,12 @@ pub fn generate_project_builder<'a>(
     args: &'a clap::ArgMatches,
     config: &'a config::Config,
     p: &'a mut ProjectBuilder<'a>,
-) -> Result<GLProject<'a>>
-{
-    match (config.projectid, args.value_of("id")) {
-        (None, Some(a_id)) => p.project(a_id),
-        (Some(c_id), None) => p.project(c_id),
-        (Some(_), Some(a_id)) => p.project(a_id),
-        (None, None) =>
-            return Err(anyhow!("No project ID passed and project not attached to the current repo. Run `git lab project attach`"))
-    };
+) -> Result<GLProject<'a>> {
 
-    p.build().map_err(|e| anyhow!("Could not construct query to fetch project URL from server.\n {}",e))
+    let project_id = utils::get_proj_from_arg_or_conf(&args, &config)?;
+    p.project(project_id);
+    p.build()
+        .map_err(|e| anyhow!("Could not construct query to fetch project URL from server.\n {}",e))
 }
 
 pub fn open_project_cmd(args: clap::ArgMatches, config: config::Config, gitlabclient: Client) -> Result<()> {
